@@ -142,3 +142,15 @@ def bpm_to_time(
             count = float(numerator) / float(denominator)
     time_segs = time_sig.split("/")
     return (60.00 / float(bpm)) * float(time_segs[0]) * float(count) * 1000.0
+
+
+def rescale(x, range_x, range_y, sig_digits=3):
+
+    # Figure out how 'wide' each range is
+    x_span = max(range_x) - min(range_x)
+    y_span = max(range_y) - min(range_y)
+
+    # Compute the scale factor between left and right values
+    scale_factor = float(y_span) / float(x_span)
+
+    return round(min(range_y) + (x - min(range_x)) * scale_factor, sig_digits)
